imageeditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# imageeditor

class `camelot.view.controls.editors.imageeditor.` `ImageEditor`(parent=None, storage=None, preview_width=100, preview_height=100, field_name='image', **kwargs)

  Editor to view and edit image files, this is a customized implementation of a FileEditor

  `checkin_byte_array`(byte_array, suffix)

    Check a byte_array into the storage

  `copy_to_clipboard`()

    Copy the image to the clipboard

  `paste_from_clipboard`()

    Paste an image from the clipboard into the editor

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus